# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class NonBMSTORApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def balancing_nonbm_stor_events_get(self, count, **kwargs):  # noqa: E501
        """Non-BM STOR events (NONBM)  # noqa: E501

        This endpoint provides data about the start of NGESO Short Term Operating Reserves (STOR) events. This is  activity that is outside of the Balancing Mechanism and takes place to meet the need to  increase generation or decrease demand. Each result has a non-zero generation value which was preceded by a zero  generation value.                By default, the before parameter filters the data by start time. If the settlementPeriodBefore parameter is  provided, the before parameter instead filters on settlement date, allowing for searching by start time or  settlement date & settlement period.  Note: When filtering via settlement date, before is treated as a Date only, with the time being ignored. For  example, 2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering latest 3 events:                    /balancing/nonbm/stor/events?count=3                Filtering latest 3 events before start time:                    /balancing/nonbm/stor/events?before=2022-08-01T00:00Z&count=3                Filtering latest 3 events before settlement date and settlement period:                    /balancing/nonbm/stor/events?before=2022-08-01T00:00Z&settlementPeriodBefore=48&count=3  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_nonbm_stor_events_get(count, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int count: The number of events to return. (required)
        :param datetime before: If specified, filters events to those with a start time before or at the date, or a settlement date before the date if  settlementPeriodBefore is also specified.  If omitted, latest events are returned.
        :param int settlement_period_before: Filters events to those with a settlement period before or at the value.  Before parameter must be specified if this is specified.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNonBmStorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_nonbm_stor_events_get_with_http_info(count, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_nonbm_stor_events_get_with_http_info(count, **kwargs)  # noqa: E501
            return data

    def balancing_nonbm_stor_events_get_with_http_info(self, count, **kwargs):  # noqa: E501
        """Non-BM STOR events (NONBM)  # noqa: E501

        This endpoint provides data about the start of NGESO Short Term Operating Reserves (STOR) events. This is  activity that is outside of the Balancing Mechanism and takes place to meet the need to  increase generation or decrease demand. Each result has a non-zero generation value which was preceded by a zero  generation value.                By default, the before parameter filters the data by start time. If the settlementPeriodBefore parameter is  provided, the before parameter instead filters on settlement date, allowing for searching by start time or  settlement date & settlement period.  Note: When filtering via settlement date, before is treated as a Date only, with the time being ignored. For  example, 2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering latest 3 events:                    /balancing/nonbm/stor/events?count=3                Filtering latest 3 events before start time:                    /balancing/nonbm/stor/events?before=2022-08-01T00:00Z&count=3                Filtering latest 3 events before settlement date and settlement period:                    /balancing/nonbm/stor/events?before=2022-08-01T00:00Z&settlementPeriodBefore=48&count=3  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_nonbm_stor_events_get_with_http_info(count, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int count: The number of events to return. (required)
        :param datetime before: If specified, filters events to those with a start time before or at the date, or a settlement date before the date if  settlementPeriodBefore is also specified.  If omitted, latest events are returned.
        :param int settlement_period_before: Filters events to those with a settlement period before or at the value.  Before parameter must be specified if this is specified.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNonBmStorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['count', 'before', 'settlement_period_before', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_nonbm_stor_events_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'count' is set
        if ('count' not in params or
                params['count'] is None):
            raise ValueError("Missing the required parameter `count` when calling `balancing_nonbm_stor_events_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'before' in params:
            query_params.append(('before', params['before']))  # noqa: E501
        if 'settlement_period_before' in params:
            query_params.append(('settlementPeriodBefore', params['settlement_period_before']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/nonbm/stor/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNonBmStorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_nonbm_stor_get(self, _from, to, **kwargs):  # noqa: E501
        """Non-BM STOR time series (NONBM)  # noqa: E501

        This endpoint provides data about the Short Term Operating Reserves (STOR) that have been made use of  by NGESO. This is activity that is outside of the Balancing Mechanism and takes place to meet the need to  increase generation or decrease demand.                By default, the from and to parameters filter the data by time inclusively. If the settlementPeriodFrom or  settlementPeriodTo parameters are provided, the corresponding from or to parameter instead filters on settlement  date, allowing for searching by a combination of time and/or settlement date & settlement period.  Note: When filtering via settlement date, from/to are treated as Dates only, with the time being ignored. For  example, 2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering from start time to start time:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z                Filtering from start time to settlement date and period:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodTo=1                Filtering from settlement date and period to start time:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1                Filtering from settlement date and period to settlement date and period:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1&settlementPeriodTo=1  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_nonbm_stor_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: The \"from\" start time or settlement date for the filter. (required)
        :param datetime to: The \"to\" start time or settlement date for the filter. (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param bool include_zero: Include data points with a generation of zero.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNonBmStorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_nonbm_stor_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_nonbm_stor_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def balancing_nonbm_stor_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Non-BM STOR time series (NONBM)  # noqa: E501

        This endpoint provides data about the Short Term Operating Reserves (STOR) that have been made use of  by NGESO. This is activity that is outside of the Balancing Mechanism and takes place to meet the need to  increase generation or decrease demand.                By default, the from and to parameters filter the data by time inclusively. If the settlementPeriodFrom or  settlementPeriodTo parameters are provided, the corresponding from or to parameter instead filters on settlement  date, allowing for searching by a combination of time and/or settlement date & settlement period.  Note: When filtering via settlement date, from/to are treated as Dates only, with the time being ignored. For  example, 2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering from start time to start time:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z                Filtering from start time to settlement date and period:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodTo=1                Filtering from settlement date and period to start time:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1                Filtering from settlement date and period to settlement date and period:                    /balancing/nonbm/stor?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1&settlementPeriodTo=1  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_nonbm_stor_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: The \"from\" start time or settlement date for the filter. (required)
        :param datetime to: The \"to\" start time or settlement date for the filter. (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param bool include_zero: Include data points with a generation of zero.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNonBmStorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'settlement_period_from', 'settlement_period_to', 'include_zero', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_nonbm_stor_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `balancing_nonbm_stor_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `balancing_nonbm_stor_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'settlement_period_from' in params:
            query_params.append(('settlementPeriodFrom', params['settlement_period_from']))  # noqa: E501
        if 'settlement_period_to' in params:
            query_params.append(('settlementPeriodTo', params['settlement_period_to']))  # noqa: E501
        if 'include_zero' in params:
            query_params.append(('includeZero', params['include_zero']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/nonbm/stor', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingNonBmStorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class SystemApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def system_demand_control_instructions_get(self, **kwargs):  # noqa: E501
        """Demand control instructions (DCI)  # noqa: E501

        This endpoint provides demand control instruction data, filtered by the time range of the instruction.  There is no date range limit on parameters.  If no query parameters are supplied all data is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_demand_control_instructions_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscDemandControlInstructionData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.system_demand_control_instructions_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.system_demand_control_instructions_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def system_demand_control_instructions_get_with_http_info(self, **kwargs):  # noqa: E501
        """Demand control instructions (DCI)  # noqa: E501

        This endpoint provides demand control instruction data, filtered by the time range of the instruction.  There is no date range limit on parameters.  If no query parameters are supplied all data is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_demand_control_instructions_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscDemandControlInstructionData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method system_demand_control_instructions_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/system/demand-control-instructions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscDemandControlInstructionData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def system_frequency_get(self, **kwargs):  # noqa: E501
        """System frequency (FREQ)  # noqa: E501

        This endpoint allows for retrieving a collection of recent system frequency data from National Grid ESO. Results  can be filtered by a range of DateTime parameters. This endpoint is useful for ad-hoc querying frequency data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_frequency_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemFrequency
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.system_frequency_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.system_frequency_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def system_frequency_get_with_http_info(self, **kwargs):  # noqa: E501
        """System frequency (FREQ)  # noqa: E501

        This endpoint allows for retrieving a collection of recent system frequency data from National Grid ESO. Results  can be filtered by a range of DateTime parameters. This endpoint is useful for ad-hoc querying frequency data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_frequency_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemFrequency
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method system_frequency_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/system/frequency', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemFrequency',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def system_frequency_stream_get(self, **kwargs):  # noqa: E501
        """System frequency (FREQ) stream  # noqa: E501

        This endpoint allows for retrieving a stream of recent system frequency data from National Grid ESO. Results can  be filtered by a range of DateTime parameters. This endpoint has an optimised JSON payload and aimed at frequent  request for the frequency data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_frequency_stream_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :return: list[InsightsApiModelsResponsesMiscSystemFrequency]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.system_frequency_stream_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.system_frequency_stream_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def system_frequency_stream_get_with_http_info(self, **kwargs):  # noqa: E501
        """System frequency (FREQ) stream  # noqa: E501

        This endpoint allows for retrieving a stream of recent system frequency data from National Grid ESO. Results can  be filtered by a range of DateTime parameters. This endpoint has an optimised JSON payload and aimed at frequent  request for the frequency data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_frequency_stream_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :return: list[InsightsApiModelsResponsesMiscSystemFrequency]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method system_frequency_stream_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/system/frequency/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsResponsesMiscSystemFrequency]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def system_warnings_get(self, **kwargs):  # noqa: E501
        """System warnings (SYSWARN)  # noqa: E501

        This endpoint provides system warnings data. Results can be filtered by warning type and a range of DateTime parameters.  - If no parameters are specified then the latest message is returned  - If just a warning type is specified then the latest message of that type is returned  - If just publish times are specified then all messages within that range are returned  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_warnings_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str warning_type:
        :param datetime publish_date_time_from:
        :param datetime publish_date_time_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemWarningsData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.system_warnings_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.system_warnings_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def system_warnings_get_with_http_info(self, **kwargs):  # noqa: E501
        """System warnings (SYSWARN)  # noqa: E501

        This endpoint provides system warnings data. Results can be filtered by warning type and a range of DateTime parameters.  - If no parameters are specified then the latest message is returned  - If just a warning type is specified then the latest message of that type is returned  - If just publish times are specified then all messages within that range are returned  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.system_warnings_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str warning_type:
        :param datetime publish_date_time_from:
        :param datetime publish_date_time_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemWarningsData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['warning_type', 'publish_date_time_from', 'publish_date_time_to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method system_warnings_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'warning_type' in params:
            query_params.append(('warningType', params['warning_type']))  # noqa: E501
        if 'publish_date_time_from' in params:
            query_params.append(('publishDateTimeFrom', params['publish_date_time_from']))  # noqa: E501
        if 'publish_date_time_to' in params:
            query_params.append(('publishDateTimeTo', params['publish_date_time_to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/system/warnings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSystemWarningsData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiLegacyInteroperabilityLegacyRemitListItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message_id': 'str',
        'sequence_id': 'int',
        'message_heading': 'str',
        'event_type': 'str',
        'publish_date_time_string': 'str',
        'participant_market_participant_id': 'str',
        'asset_id': 'str',
        'asset_eic_code': 'str',
        'asset_type': 'str',
        'affected_unit': 'str',
        'affected_area': 'str',
        'asset_fuel_type': 'str',
        'asset_normal_capacity': 'float',
        'asset_normal_capacity_specified': 'bool',
        'available_capacity': 'float',
        'available_capacity_specified': 'bool',
        'event_start_string': 'str',
        'event_end_string': 'str',
        'duration_uncertainty': 'str',
        'cause': 'str',
        'event_status': 'str',
        'related_information': 'str',
        'active_flag': 'str',
        'revision_number': 'int',
        'message_type': 'str',
        'unavailability_type': 'str',
        'unavailable_capacity': 'float',
        'unavailable_capacity_specified': 'bool'
    }

    attribute_map = {
        'message_id': 'messageId',
        'sequence_id': 'sequenceId',
        'message_heading': 'messageHeading',
        'event_type': 'eventType',
        'publish_date_time_string': 'publishDateTimeString',
        'participant_market_participant_id': 'participantMarketParticipantId',
        'asset_id': 'assetId',
        'asset_eic_code': 'assetEicCode',
        'asset_type': 'assetType',
        'affected_unit': 'affectedUnit',
        'affected_area': 'affectedArea',
        'asset_fuel_type': 'assetFuelType',
        'asset_normal_capacity': 'assetNormalCapacity',
        'asset_normal_capacity_specified': 'assetNormalCapacitySpecified',
        'available_capacity': 'availableCapacity',
        'available_capacity_specified': 'availableCapacitySpecified',
        'event_start_string': 'eventStartString',
        'event_end_string': 'eventEndString',
        'duration_uncertainty': 'durationUncertainty',
        'cause': 'cause',
        'event_status': 'eventStatus',
        'related_information': 'relatedInformation',
        'active_flag': 'activeFlag',
        'revision_number': 'revisionNumber',
        'message_type': 'messageType',
        'unavailability_type': 'unavailabilityType',
        'unavailable_capacity': 'unavailableCapacity',
        'unavailable_capacity_specified': 'unavailableCapacitySpecified'
    }

    def __init__(self, message_id=None, sequence_id=None, message_heading=None, event_type=None, publish_date_time_string=None, participant_market_participant_id=None, asset_id=None, asset_eic_code=None, asset_type=None, affected_unit=None, affected_area=None, asset_fuel_type=None, asset_normal_capacity=None, asset_normal_capacity_specified=None, available_capacity=None, available_capacity_specified=None, event_start_string=None, event_end_string=None, duration_uncertainty=None, cause=None, event_status=None, related_information=None, active_flag=None, revision_number=None, message_type=None, unavailability_type=None, unavailable_capacity=None, unavailable_capacity_specified=None):  # noqa: E501
        """InsightsApiLegacyInteroperabilityLegacyRemitListItem - a model defined in Swagger"""  # noqa: E501
        self._message_id = None
        self._sequence_id = None
        self._message_heading = None
        self._event_type = None
        self._publish_date_time_string = None
        self._participant_market_participant_id = None
        self._asset_id = None
        self._asset_eic_code = None
        self._asset_type = None
        self._affected_unit = None
        self._affected_area = None
        self._asset_fuel_type = None
        self._asset_normal_capacity = None
        self._asset_normal_capacity_specified = None
        self._available_capacity = None
        self._available_capacity_specified = None
        self._event_start_string = None
        self._event_end_string = None
        self._duration_uncertainty = None
        self._cause = None
        self._event_status = None
        self._related_information = None
        self._active_flag = None
        self._revision_number = None
        self._message_type = None
        self._unavailability_type = None
        self._unavailable_capacity = None
        self._unavailable_capacity_specified = None
        self.discriminator = None
        if message_id is not None:
            self.message_id = message_id
        if sequence_id is not None:
            self.sequence_id = sequence_id
        if message_heading is not None:
            self.message_heading = message_heading
        if event_type is not None:
            self.event_type = event_type
        if publish_date_time_string is not None:
            self.publish_date_time_string = publish_date_time_string
        if participant_market_participant_id is not None:
            self.participant_market_participant_id = participant_market_participant_id
        if asset_id is not None:
            self.asset_id = asset_id
        if asset_eic_code is not None:
            self.asset_eic_code = asset_eic_code
        if asset_type is not None:
            self.asset_type = asset_type
        if affected_unit is not None:
            self.affected_unit = affected_unit
        if affected_area is not None:
            self.affected_area = affected_area
        if asset_fuel_type is not None:
            self.asset_fuel_type = asset_fuel_type
        if asset_normal_capacity is not None:
            self.asset_normal_capacity = asset_normal_capacity
        if asset_normal_capacity_specified is not None:
            self.asset_normal_capacity_specified = asset_normal_capacity_specified
        if available_capacity is not None:
            self.available_capacity = available_capacity
        if available_capacity_specified is not None:
            self.available_capacity_specified = available_capacity_specified
        if event_start_string is not None:
            self.event_start_string = event_start_string
        if event_end_string is not None:
            self.event_end_string = event_end_string
        if duration_uncertainty is not None:
            self.duration_uncertainty = duration_uncertainty
        if cause is not None:
            self.cause = cause
        if event_status is not None:
            self.event_status = event_status
        if related_information is not None:
            self.related_information = related_information
        if active_flag is not None:
            self.active_flag = active_flag
        if revision_number is not None:
            self.revision_number = revision_number
        if message_type is not None:
            self.message_type = message_type
        if unavailability_type is not None:
            self.unavailability_type = unavailability_type
        if unavailable_capacity is not None:
            self.unavailable_capacity = unavailable_capacity
        if unavailable_capacity_specified is not None:
            self.unavailable_capacity_specified = unavailable_capacity_specified

    @property
    def message_id(self):
        """Gets the message_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The message_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param message_id: The message_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._message_id = message_id

    @property
    def sequence_id(self):
        """Gets the sequence_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The sequence_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: int
        """
        return self._sequence_id

    @sequence_id.setter
    def sequence_id(self, sequence_id):
        """Sets the sequence_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param sequence_id: The sequence_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: int
        """

        self._sequence_id = sequence_id

    @property
    def message_heading(self):
        """Gets the message_heading of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The message_heading of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._message_heading

    @message_heading.setter
    def message_heading(self, message_heading):
        """Sets the message_heading of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param message_heading: The message_heading of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._message_heading = message_heading

    @property
    def event_type(self):
        """Gets the event_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The event_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param event_type: The event_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def publish_date_time_string(self):
        """Gets the publish_date_time_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The publish_date_time_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._publish_date_time_string

    @publish_date_time_string.setter
    def publish_date_time_string(self, publish_date_time_string):
        """Sets the publish_date_time_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param publish_date_time_string: The publish_date_time_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._publish_date_time_string = publish_date_time_string

    @property
    def participant_market_participant_id(self):
        """Gets the participant_market_participant_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The participant_market_participant_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._participant_market_participant_id

    @participant_market_participant_id.setter
    def participant_market_participant_id(self, participant_market_participant_id):
        """Sets the participant_market_participant_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param participant_market_participant_id: The participant_market_participant_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._participant_market_participant_id = participant_market_participant_id

    @property
    def asset_id(self):
        """Gets the asset_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The asset_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param asset_id: The asset_id of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._asset_id = asset_id

    @property
    def asset_eic_code(self):
        """Gets the asset_eic_code of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The asset_eic_code of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._asset_eic_code

    @asset_eic_code.setter
    def asset_eic_code(self, asset_eic_code):
        """Sets the asset_eic_code of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param asset_eic_code: The asset_eic_code of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._asset_eic_code = asset_eic_code

    @property
    def asset_type(self):
        """Gets the asset_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The asset_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param asset_type: The asset_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._asset_type = asset_type

    @property
    def affected_unit(self):
        """Gets the affected_unit of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The affected_unit of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._affected_unit

    @affected_unit.setter
    def affected_unit(self, affected_unit):
        """Sets the affected_unit of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param affected_unit: The affected_unit of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._affected_unit = affected_unit

    @property
    def affected_area(self):
        """Gets the affected_area of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The affected_area of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._affected_area

    @affected_area.setter
    def affected_area(self, affected_area):
        """Sets the affected_area of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param affected_area: The affected_area of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._affected_area = affected_area

    @property
    def asset_fuel_type(self):
        """Gets the asset_fuel_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The asset_fuel_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._asset_fuel_type

    @asset_fuel_type.setter
    def asset_fuel_type(self, asset_fuel_type):
        """Sets the asset_fuel_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param asset_fuel_type: The asset_fuel_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._asset_fuel_type = asset_fuel_type

    @property
    def asset_normal_capacity(self):
        """Gets the asset_normal_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The asset_normal_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: float
        """
        return self._asset_normal_capacity

    @asset_normal_capacity.setter
    def asset_normal_capacity(self, asset_normal_capacity):
        """Sets the asset_normal_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param asset_normal_capacity: The asset_normal_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: float
        """

        self._asset_normal_capacity = asset_normal_capacity

    @property
    def asset_normal_capacity_specified(self):
        """Gets the asset_normal_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The asset_normal_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: bool
        """
        return self._asset_normal_capacity_specified

    @asset_normal_capacity_specified.setter
    def asset_normal_capacity_specified(self, asset_normal_capacity_specified):
        """Sets the asset_normal_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param asset_normal_capacity_specified: The asset_normal_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: bool
        """

        self._asset_normal_capacity_specified = asset_normal_capacity_specified

    @property
    def available_capacity(self):
        """Gets the available_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The available_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: float
        """
        return self._available_capacity

    @available_capacity.setter
    def available_capacity(self, available_capacity):
        """Sets the available_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param available_capacity: The available_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: float
        """

        self._available_capacity = available_capacity

    @property
    def available_capacity_specified(self):
        """Gets the available_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The available_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: bool
        """
        return self._available_capacity_specified

    @available_capacity_specified.setter
    def available_capacity_specified(self, available_capacity_specified):
        """Sets the available_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param available_capacity_specified: The available_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: bool
        """

        self._available_capacity_specified = available_capacity_specified

    @property
    def event_start_string(self):
        """Gets the event_start_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The event_start_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._event_start_string

    @event_start_string.setter
    def event_start_string(self, event_start_string):
        """Sets the event_start_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param event_start_string: The event_start_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._event_start_string = event_start_string

    @property
    def event_end_string(self):
        """Gets the event_end_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The event_end_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._event_end_string

    @event_end_string.setter
    def event_end_string(self, event_end_string):
        """Sets the event_end_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param event_end_string: The event_end_string of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._event_end_string = event_end_string

    @property
    def duration_uncertainty(self):
        """Gets the duration_uncertainty of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The duration_uncertainty of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._duration_uncertainty

    @duration_uncertainty.setter
    def duration_uncertainty(self, duration_uncertainty):
        """Sets the duration_uncertainty of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param duration_uncertainty: The duration_uncertainty of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._duration_uncertainty = duration_uncertainty

    @property
    def cause(self):
        """Gets the cause of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The cause of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._cause

    @cause.setter
    def cause(self, cause):
        """Sets the cause of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param cause: The cause of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._cause = cause

    @property
    def event_status(self):
        """Gets the event_status of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The event_status of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._event_status

    @event_status.setter
    def event_status(self, event_status):
        """Sets the event_status of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param event_status: The event_status of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._event_status = event_status

    @property
    def related_information(self):
        """Gets the related_information of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The related_information of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._related_information

    @related_information.setter
    def related_information(self, related_information):
        """Sets the related_information of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param related_information: The related_information of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._related_information = related_information

    @property
    def active_flag(self):
        """Gets the active_flag of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The active_flag of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._active_flag

    @active_flag.setter
    def active_flag(self, active_flag):
        """Sets the active_flag of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param active_flag: The active_flag of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._active_flag = active_flag

    @property
    def revision_number(self):
        """Gets the revision_number of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The revision_number of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: int
        """
        return self._revision_number

    @revision_number.setter
    def revision_number(self, revision_number):
        """Sets the revision_number of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param revision_number: The revision_number of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: int
        """

        self._revision_number = revision_number

    @property
    def message_type(self):
        """Gets the message_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The message_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._message_type

    @message_type.setter
    def message_type(self, message_type):
        """Sets the message_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param message_type: The message_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._message_type = message_type

    @property
    def unavailability_type(self):
        """Gets the unavailability_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The unavailability_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: str
        """
        return self._unavailability_type

    @unavailability_type.setter
    def unavailability_type(self, unavailability_type):
        """Sets the unavailability_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param unavailability_type: The unavailability_type of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: str
        """

        self._unavailability_type = unavailability_type

    @property
    def unavailable_capacity(self):
        """Gets the unavailable_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The unavailable_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: float
        """
        return self._unavailable_capacity

    @unavailable_capacity.setter
    def unavailable_capacity(self, unavailable_capacity):
        """Sets the unavailable_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param unavailable_capacity: The unavailable_capacity of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: float
        """

        self._unavailable_capacity = unavailable_capacity

    @property
    def unavailable_capacity_specified(self):
        """Gets the unavailable_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501


        :return: The unavailable_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :rtype: bool
        """
        return self._unavailable_capacity_specified

    @unavailable_capacity_specified.setter
    def unavailable_capacity_specified(self, unavailable_capacity_specified):
        """Sets the unavailable_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.


        :param unavailable_capacity_specified: The unavailable_capacity_specified of this InsightsApiLegacyInteroperabilityLegacyRemitListItem.  # noqa: E501
        :type: bool
        """

        self._unavailable_capacity_specified = unavailable_capacity_specified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiLegacyInteroperabilityLegacyRemitListItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiLegacyInteroperabilityLegacyRemitListItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.demand_api import DemandApi  # noqa: E501
from elexonpy.rest import ApiException


class TestDemandApi(unittest.TestCase):
    """DemandApi unit test stubs"""

    def setUp(self):
        self.api = DemandApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_demand_actual_total_get(self):
        """Test case for demand_actual_total_get

        Actual total load (ATL/B0610)  # noqa: E501
        """
        pass

    def test_demand_get(self):
        """Test case for demand_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_demand_outturn_daily_get(self):
        """Test case for demand_outturn_daily_get

        Initial National Demand outturn per day (INDOD)  # noqa: E501
        """
        pass

    def test_demand_outturn_daily_stream_get(self):
        """Test case for demand_outturn_daily_stream_get

        Initial National Demand outturn per day (INDOD) stream  # noqa: E501
        """
        pass

    def test_demand_outturn_get(self):
        """Test case for demand_outturn_get

        Initial National Demand outturn (INDO)  # noqa: E501
        """
        pass

    def test_demand_outturn_stream_get(self):
        """Test case for demand_outturn_stream_get

        Initial National Demand outturn (INDO) stream  # noqa: E501
        """
        pass

    def test_demand_outturn_summary_get(self):
        """Test case for demand_outturn_summary_get

        System demand summary (FUELINST)  # noqa: E501
        """
        pass

    def test_demand_peak_get(self):
        """Test case for demand_peak_get

        Peak demand per day (ITSDO)  # noqa: E501
        """
        pass

    def test_demand_peak_indicative_get(self):
        """Test case for demand_peak_indicative_get

        Indicative peak demand per day (S0142, ITSDO, FUELHH)  # noqa: E501
        """
        pass

    def test_demand_peak_indicative_operational_triad_season_get(self):
        """Test case for demand_peak_indicative_operational_triad_season_get

        Operational data demand peaks for a Triad season (ITSDO, FUELHH)  # noqa: E501
        """
        pass

    def test_demand_peak_indicative_settlement_triad_season_get(self):
        """Test case for demand_peak_indicative_settlement_triad_season_get

        Settlement data demand peaks for a Triad season (S0142)  # noqa: E501
        """
        pass

    def test_demand_peak_triad_get(self):
        """Test case for demand_peak_triad_get

        Triad demand peaks (S0142, ITSDO, FUELHH)  # noqa: E501
        """
        pass

    def test_demand_rolling_system_demand_get(self):
        """Test case for demand_rolling_system_demand_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_demand_stream_get(self):
        """Test case for demand_stream_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_demand_summary_get(self):
        """Test case for demand_summary_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_demand_total_actual_get(self):
        """Test case for demand_total_actual_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesReferenceBmUnitData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'national_grid_bm_unit': 'str',
        'elexon_bm_unit': 'str',
        'eic': 'str',
        'fuel_type': 'str',
        'lead_party_name': 'str',
        'bm_unit_type': 'str',
        'fpn_flag': 'bool'
    }

    attribute_map = {
        'national_grid_bm_unit': 'nationalGridBmUnit',
        'elexon_bm_unit': 'elexonBmUnit',
        'eic': 'eic',
        'fuel_type': 'fuelType',
        'lead_party_name': 'leadPartyName',
        'bm_unit_type': 'bmUnitType',
        'fpn_flag': 'fpnFlag'
    }

    def __init__(self, national_grid_bm_unit=None, elexon_bm_unit=None, eic=None, fuel_type=None, lead_party_name=None, bm_unit_type=None, fpn_flag=None):  # noqa: E501
        """InsightsApiModelsResponsesReferenceBmUnitData - a model defined in Swagger"""  # noqa: E501
        self._national_grid_bm_unit = None
        self._elexon_bm_unit = None
        self._eic = None
        self._fuel_type = None
        self._lead_party_name = None
        self._bm_unit_type = None
        self._fpn_flag = None
        self.discriminator = None
        if national_grid_bm_unit is not None:
            self.national_grid_bm_unit = national_grid_bm_unit
        if elexon_bm_unit is not None:
            self.elexon_bm_unit = elexon_bm_unit
        if eic is not None:
            self.eic = eic
        if fuel_type is not None:
            self.fuel_type = fuel_type
        if lead_party_name is not None:
            self.lead_party_name = lead_party_name
        if bm_unit_type is not None:
            self.bm_unit_type = bm_unit_type
        if fpn_flag is not None:
            self.fpn_flag = fpn_flag

    @property
    def national_grid_bm_unit(self):
        """Gets the national_grid_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501


        :return: The national_grid_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :rtype: str
        """
        return self._national_grid_bm_unit

    @national_grid_bm_unit.setter
    def national_grid_bm_unit(self, national_grid_bm_unit):
        """Sets the national_grid_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.


        :param national_grid_bm_unit: The national_grid_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :type: str
        """

        self._national_grid_bm_unit = national_grid_bm_unit

    @property
    def elexon_bm_unit(self):
        """Gets the elexon_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501


        :return: The elexon_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :rtype: str
        """
        return self._elexon_bm_unit

    @elexon_bm_unit.setter
    def elexon_bm_unit(self, elexon_bm_unit):
        """Sets the elexon_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.


        :param elexon_bm_unit: The elexon_bm_unit of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :type: str
        """

        self._elexon_bm_unit = elexon_bm_unit

    @property
    def eic(self):
        """Gets the eic of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501


        :return: The eic of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :rtype: str
        """
        return self._eic

    @eic.setter
    def eic(self, eic):
        """Sets the eic of this InsightsApiModelsResponsesReferenceBmUnitData.


        :param eic: The eic of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :type: str
        """

        self._eic = eic

    @property
    def fuel_type(self):
        """Gets the fuel_type of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501


        :return: The fuel_type of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :rtype: str
        """
        return self._fuel_type

    @fuel_type.setter
    def fuel_type(self, fuel_type):
        """Sets the fuel_type of this InsightsApiModelsResponsesReferenceBmUnitData.


        :param fuel_type: The fuel_type of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :type: str
        """

        self._fuel_type = fuel_type

    @property
    def lead_party_name(self):
        """Gets the lead_party_name of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501


        :return: The lead_party_name of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :rtype: str
        """
        return self._lead_party_name

    @lead_party_name.setter
    def lead_party_name(self, lead_party_name):
        """Sets the lead_party_name of this InsightsApiModelsResponsesReferenceBmUnitData.


        :param lead_party_name: The lead_party_name of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :type: str
        """

        self._lead_party_name = lead_party_name

    @property
    def bm_unit_type(self):
        """Gets the bm_unit_type of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501


        :return: The bm_unit_type of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit_type

    @bm_unit_type.setter
    def bm_unit_type(self, bm_unit_type):
        """Sets the bm_unit_type of this InsightsApiModelsResponsesReferenceBmUnitData.


        :param bm_unit_type: The bm_unit_type of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :type: str
        """

        self._bm_unit_type = bm_unit_type

    @property
    def fpn_flag(self):
        """Gets the fpn_flag of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501


        :return: The fpn_flag of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :rtype: bool
        """
        return self._fpn_flag

    @fpn_flag.setter
    def fpn_flag(self, fpn_flag):
        """Sets the fpn_flag of this InsightsApiModelsResponsesReferenceBmUnitData.


        :param fpn_flag: The fpn_flag of this InsightsApiModelsResponsesReferenceBmUnitData.  # noqa: E501
        :type: bool
        """

        self._fpn_flag = fpn_flag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesReferenceBmUnitData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesReferenceBmUnitData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_date': 'date',
        'settlement_period': 'int',
        'start_time': 'datetime',
        'buy_action_count': 'int',
        'sell_action_count': 'int',
        'buy_price_minimum': 'float',
        'buy_price_maximum': 'float',
        'buy_price_average': 'float',
        'sell_price_minimum': 'float',
        'sell_price_maximum': 'float',
        'sell_price_average': 'float',
        'buy_volume_total': 'float',
        'sell_volume_total': 'float',
        'net_volume': 'float'
    }

    attribute_map = {
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'start_time': 'startTime',
        'buy_action_count': 'buyActionCount',
        'sell_action_count': 'sellActionCount',
        'buy_price_minimum': 'buyPriceMinimum',
        'buy_price_maximum': 'buyPriceMaximum',
        'buy_price_average': 'buyPriceAverage',
        'sell_price_minimum': 'sellPriceMinimum',
        'sell_price_maximum': 'sellPriceMaximum',
        'sell_price_average': 'sellPriceAverage',
        'buy_volume_total': 'buyVolumeTotal',
        'sell_volume_total': 'sellVolumeTotal',
        'net_volume': 'netVolume'
    }

    def __init__(self, settlement_date=None, settlement_period=None, start_time=None, buy_action_count=None, sell_action_count=None, buy_price_minimum=None, buy_price_maximum=None, buy_price_average=None, sell_price_minimum=None, sell_price_maximum=None, sell_price_average=None, buy_volume_total=None, sell_volume_total=None, net_volume=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._settlement_date = None
        self._settlement_period = None
        self._start_time = None
        self._buy_action_count = None
        self._sell_action_count = None
        self._buy_price_minimum = None
        self._buy_price_maximum = None
        self._buy_price_average = None
        self._sell_price_minimum = None
        self._sell_price_maximum = None
        self._sell_price_average = None
        self._buy_volume_total = None
        self._sell_volume_total = None
        self._net_volume = None
        self.discriminator = None
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if start_time is not None:
            self.start_time = start_time
        if buy_action_count is not None:
            self.buy_action_count = buy_action_count
        if sell_action_count is not None:
            self.sell_action_count = sell_action_count
        if buy_price_minimum is not None:
            self.buy_price_minimum = buy_price_minimum
        if buy_price_maximum is not None:
            self.buy_price_maximum = buy_price_maximum
        if buy_price_average is not None:
            self.buy_price_average = buy_price_average
        if sell_price_minimum is not None:
            self.sell_price_minimum = sell_price_minimum
        if sell_price_maximum is not None:
            self.sell_price_maximum = sell_price_maximum
        if sell_price_average is not None:
            self.sell_price_average = sell_price_average
        if buy_volume_total is not None:
            self.buy_volume_total = buy_volume_total
        if sell_volume_total is not None:
            self.sell_volume_total = sell_volume_total
        if net_volume is not None:
            self.net_volume = net_volume

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param start_time: The start_time of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def buy_action_count(self):
        """Gets the buy_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The buy_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._buy_action_count

    @buy_action_count.setter
    def buy_action_count(self, buy_action_count):
        """Sets the buy_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param buy_action_count: The buy_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: int
        """

        self._buy_action_count = buy_action_count

    @property
    def sell_action_count(self):
        """Gets the sell_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The sell_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._sell_action_count

    @sell_action_count.setter
    def sell_action_count(self, sell_action_count):
        """Sets the sell_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param sell_action_count: The sell_action_count of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: int
        """

        self._sell_action_count = sell_action_count

    @property
    def buy_price_minimum(self):
        """Gets the buy_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The buy_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._buy_price_minimum

    @buy_price_minimum.setter
    def buy_price_minimum(self, buy_price_minimum):
        """Sets the buy_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param buy_price_minimum: The buy_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._buy_price_minimum = buy_price_minimum

    @property
    def buy_price_maximum(self):
        """Gets the buy_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The buy_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._buy_price_maximum

    @buy_price_maximum.setter
    def buy_price_maximum(self, buy_price_maximum):
        """Sets the buy_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param buy_price_maximum: The buy_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._buy_price_maximum = buy_price_maximum

    @property
    def buy_price_average(self):
        """Gets the buy_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The buy_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._buy_price_average

    @buy_price_average.setter
    def buy_price_average(self, buy_price_average):
        """Sets the buy_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param buy_price_average: The buy_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._buy_price_average = buy_price_average

    @property
    def sell_price_minimum(self):
        """Gets the sell_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The sell_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._sell_price_minimum

    @sell_price_minimum.setter
    def sell_price_minimum(self, sell_price_minimum):
        """Sets the sell_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param sell_price_minimum: The sell_price_minimum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._sell_price_minimum = sell_price_minimum

    @property
    def sell_price_maximum(self):
        """Gets the sell_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The sell_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._sell_price_maximum

    @sell_price_maximum.setter
    def sell_price_maximum(self, sell_price_maximum):
        """Sets the sell_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param sell_price_maximum: The sell_price_maximum of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._sell_price_maximum = sell_price_maximum

    @property
    def sell_price_average(self):
        """Gets the sell_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The sell_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._sell_price_average

    @sell_price_average.setter
    def sell_price_average(self, sell_price_average):
        """Sets the sell_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param sell_price_average: The sell_price_average of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._sell_price_average = sell_price_average

    @property
    def buy_volume_total(self):
        """Gets the buy_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The buy_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._buy_volume_total

    @buy_volume_total.setter
    def buy_volume_total(self, buy_volume_total):
        """Sets the buy_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param buy_volume_total: The buy_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._buy_volume_total = buy_volume_total

    @property
    def sell_volume_total(self):
        """Gets the sell_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The sell_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._sell_volume_total

    @sell_volume_total.setter
    def sell_volume_total(self, sell_volume_total):
        """Sets the sell_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param sell_volume_total: The sell_volume_total of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._sell_volume_total = sell_volume_total

    @property
    def net_volume(self):
        """Gets the net_volume of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501


        :return: The net_volume of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._net_volume

    @net_volume.setter
    def net_volume(self, net_volume):
        """Sets the net_volume of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.


        :param net_volume: The net_volume of this InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse.  # noqa: E501
        :type: float
        """

        self._net_volume = net_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingDisaggregatedBalancingServicesAdjustmentSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.generation_api import GenerationApi  # noqa: E501
from elexonpy.rest import ApiException


class TestGenerationApi(unittest.TestCase):
    """GenerationApi unit test stubs"""

    def setUp(self):
        self.api = GenerationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generation_actual_per_type_day_total_get(self):
        """Test case for generation_actual_per_type_day_total_get

        Current snapshot of actual generation by fuel type categories (AGPT/B1620)  # noqa: E501
        """
        pass

    def test_generation_actual_per_type_get(self):
        """Test case for generation_actual_per_type_get

        Historic actual generation automatically down-sampled (AGPT/B1620)  # noqa: E501
        """
        pass

    def test_generation_actual_per_type_wind_and_solar_get(self):
        """Test case for generation_actual_per_type_wind_and_solar_get

        Historic actual or estimated wind and solar power generation (AGWS/B1630)  # noqa: E501
        """
        pass

    def test_generation_outturn_current_get(self):
        """Test case for generation_outturn_current_get

        Current snapshot of generation by fuel type categories (FUELINST, FUELHH)  # noqa: E501
        """
        pass

    def test_generation_outturn_fuelinsthhcur_get(self):
        """Test case for generation_outturn_fuelinsthhcur_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_generation_outturn_get(self):
        """Test case for generation_outturn_get

        Total generation outturn (FUELINST)  # noqa: E501
        """
        pass

    def test_generation_outturn_half_hourly_interconnector_get(self):
        """Test case for generation_outturn_half_hourly_interconnector_get

        This endpoint is obsolete, and this location may be removed with no further notice.   # noqa: E501
        """
        pass

    def test_generation_outturn_interconnectors_get(self):
        """Test case for generation_outturn_interconnectors_get

        Historic half-hourly interconnector flows (FUELINST)  # noqa: E501
        """
        pass

    def test_generation_outturn_summary_get(self):
        """Test case for generation_outturn_summary_get

        Historic generation automatically down-sampled (FUELINST)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'document_id': 'str',
        'document_revision_number': 'int',
        'publish_time': 'datetime',
        'process_type': 'str',
        'business_type': 'str',
        'psr_type': 'str',
        'quantity': 'float',
        'start_time': 'datetime',
        'settlement_date': 'date',
        'settlement_period': 'int'
    }

    attribute_map = {
        'dataset': 'dataset',
        'document_id': 'documentId',
        'document_revision_number': 'documentRevisionNumber',
        'publish_time': 'publishTime',
        'process_type': 'processType',
        'business_type': 'businessType',
        'psr_type': 'psrType',
        'quantity': 'quantity',
        'start_time': 'startTime',
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod'
    }

    def __init__(self, dataset=None, document_id=None, document_revision_number=None, publish_time=None, process_type=None, business_type=None, psr_type=None, quantity=None, start_time=None, settlement_date=None, settlement_period=None):  # noqa: E501
        """InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._document_id = None
        self._document_revision_number = None
        self._publish_time = None
        self._process_type = None
        self._business_type = None
        self._psr_type = None
        self._quantity = None
        self._start_time = None
        self._settlement_date = None
        self._settlement_period = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if document_id is not None:
            self.document_id = document_id
        if document_revision_number is not None:
            self.document_revision_number = document_revision_number
        if publish_time is not None:
            self.publish_time = publish_time
        if process_type is not None:
            self.process_type = process_type
        if business_type is not None:
            self.business_type = business_type
        if psr_type is not None:
            self.psr_type = psr_type
        if quantity is not None:
            self.quantity = quantity
        if start_time is not None:
            self.start_time = start_time
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param dataset: The dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def document_id(self):
        """Gets the document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param document_id: The document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def document_revision_number(self):
        """Gets the document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._document_revision_number

    @document_revision_number.setter
    def document_revision_number(self, document_revision_number):
        """Sets the document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param document_revision_number: The document_revision_number of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: int
        """

        self._document_revision_number = document_revision_number

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def process_type(self):
        """Gets the process_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The process_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._process_type

    @process_type.setter
    def process_type(self, process_type):
        """Sets the process_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param process_type: The process_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: str
        """

        self._process_type = process_type

    @property
    def business_type(self):
        """Gets the business_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The business_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._business_type

    @business_type.setter
    def business_type(self, business_type):
        """Sets the business_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param business_type: The business_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: str
        """

        self._business_type = business_type

    @property
    def psr_type(self):
        """Gets the psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._psr_type

    @psr_type.setter
    def psr_type(self, psr_type):
        """Sets the psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param psr_type: The psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: str
        """

        self._psr_type = psr_type

    @property
    def quantity(self):
        """Gets the quantity of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The quantity of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param quantity: The quantity of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: float
        """

        self._quantity = quantity

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param start_time: The start_time of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesTransparencyDatasetRowsDayAheadGenerationForWindAndSolarDatasetRow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesMiscSoSoPrices(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contract_identification': 'str',
        'trade_direction': 'str',
        'trade_quantity': 'float',
        'trade_price': 'float',
        'trader_unit': 'str',
        'start_time': 'datetime',
        'settlement_date': 'date'
    }

    attribute_map = {
        'contract_identification': 'contractIdentification',
        'trade_direction': 'tradeDirection',
        'trade_quantity': 'tradeQuantity',
        'trade_price': 'tradePrice',
        'trader_unit': 'traderUnit',
        'start_time': 'startTime',
        'settlement_date': 'settlementDate'
    }

    def __init__(self, contract_identification=None, trade_direction=None, trade_quantity=None, trade_price=None, trader_unit=None, start_time=None, settlement_date=None):  # noqa: E501
        """InsightsApiModelsResponsesMiscSoSoPrices - a model defined in Swagger"""  # noqa: E501
        self._contract_identification = None
        self._trade_direction = None
        self._trade_quantity = None
        self._trade_price = None
        self._trader_unit = None
        self._start_time = None
        self._settlement_date = None
        self.discriminator = None
        if contract_identification is not None:
            self.contract_identification = contract_identification
        if trade_direction is not None:
            self.trade_direction = trade_direction
        if trade_quantity is not None:
            self.trade_quantity = trade_quantity
        if trade_price is not None:
            self.trade_price = trade_price
        if trader_unit is not None:
            self.trader_unit = trader_unit
        if start_time is not None:
            self.start_time = start_time
        if settlement_date is not None:
            self.settlement_date = settlement_date

    @property
    def contract_identification(self):
        """Gets the contract_identification of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501


        :return: The contract_identification of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :rtype: str
        """
        return self._contract_identification

    @contract_identification.setter
    def contract_identification(self, contract_identification):
        """Sets the contract_identification of this InsightsApiModelsResponsesMiscSoSoPrices.


        :param contract_identification: The contract_identification of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :type: str
        """

        self._contract_identification = contract_identification

    @property
    def trade_direction(self):
        """Gets the trade_direction of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501


        :return: The trade_direction of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :rtype: str
        """
        return self._trade_direction

    @trade_direction.setter
    def trade_direction(self, trade_direction):
        """Sets the trade_direction of this InsightsApiModelsResponsesMiscSoSoPrices.


        :param trade_direction: The trade_direction of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :type: str
        """

        self._trade_direction = trade_direction

    @property
    def trade_quantity(self):
        """Gets the trade_quantity of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501


        :return: The trade_quantity of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :rtype: float
        """
        return self._trade_quantity

    @trade_quantity.setter
    def trade_quantity(self, trade_quantity):
        """Sets the trade_quantity of this InsightsApiModelsResponsesMiscSoSoPrices.


        :param trade_quantity: The trade_quantity of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :type: float
        """

        self._trade_quantity = trade_quantity

    @property
    def trade_price(self):
        """Gets the trade_price of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501


        :return: The trade_price of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :rtype: float
        """
        return self._trade_price

    @trade_price.setter
    def trade_price(self, trade_price):
        """Sets the trade_price of this InsightsApiModelsResponsesMiscSoSoPrices.


        :param trade_price: The trade_price of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :type: float
        """

        self._trade_price = trade_price

    @property
    def trader_unit(self):
        """Gets the trader_unit of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501


        :return: The trader_unit of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :rtype: str
        """
        return self._trader_unit

    @trader_unit.setter
    def trader_unit(self, trader_unit):
        """Sets the trader_unit of this InsightsApiModelsResponsesMiscSoSoPrices.


        :param trader_unit: The trader_unit of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :type: str
        """

        self._trader_unit = trader_unit

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesMiscSoSoPrices.


        :param start_time: The start_time of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesMiscSoSoPrices.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesMiscSoSoPrices.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesMiscSoSoPrices, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesMiscSoSoPrices):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class SystemForecastApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def forecast_system_loss_of_load_get(self, _from, to, **kwargs):  # noqa: E501
        """Loss of load probability and de-rated margin forecast (LOLPDRM)  # noqa: E501

        This endpoint provides the 1h, 2h, 4h, 8h and 12h+ Loss of Load Probability and De-rated Margin forecasts  for each settlement period over a requested time range.                For each forecast horizon at 1, 2, 4 or 8 hours, the returned value is the forecast received that number of hours  before the start of the settlement period.                For the forecast horizon of 12h, the returned value is the most recent forecast received 12 or more hours  before the start of the settlement period. That is, if the most recent forecast was published today at 00:00,  - for 11:30 today, the 12h forecast is the one published yesterday at 23:30 (12h before)  - for 12:00 today, the 12h forecast is the one published today at 00:00 (12h before)  - for 12:30 today, the 12h forecast is the one published today at 00:00 (the latest published)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_system_loss_of_load_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscLossOfLoadProbabilityDeratedMarginResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_system_loss_of_load_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_system_loss_of_load_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_system_loss_of_load_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Loss of load probability and de-rated margin forecast (LOLPDRM)  # noqa: E501

        This endpoint provides the 1h, 2h, 4h, 8h and 12h+ Loss of Load Probability and De-rated Margin forecasts  for each settlement period over a requested time range.                For each forecast horizon at 1, 2, 4 or 8 hours, the returned value is the forecast received that number of hours  before the start of the settlement period.                For the forecast horizon of 12h, the returned value is the most recent forecast received 12 or more hours  before the start of the settlement period. That is, if the most recent forecast was published today at 00:00,  - for 11:30 today, the 12h forecast is the one published yesterday at 23:30 (12h before)  - for 12:00 today, the 12h forecast is the one published today at 00:00 (12h before)  - for 12:30 today, the 12h forecast is the one published today at 00:00 (the latest published)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_system_loss_of_load_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscLossOfLoadProbabilityDeratedMarginResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'settlement_period_from', 'settlement_period_to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_system_loss_of_load_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_system_loss_of_load_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_system_loss_of_load_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'settlement_period_from' in params:
            query_params.append(('settlementPeriodFrom', params['settlement_period_from']))  # noqa: E501
        if 'settlement_period_to' in params:
            query_params.append(('settlementPeriodTo', params['settlement_period_to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/system/loss-of-load', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscLossOfLoadProbabilityDeratedMarginResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.surplus_forecast_api import SurplusForecastApi  # noqa: E501
from elexonpy.rest import ApiException


class TestSurplusForecastApi(unittest.TestCase):
    """SurplusForecastApi unit test stubs"""

    def setUp(self):
        self.api = SurplusForecastApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_forecast_surplus_daily_evolution_get(self):
        """Test case for forecast_surplus_daily_evolution_get

        Evolution daily surplus forecast (OCNMFD)  # noqa: E501
        """
        pass

    def test_forecast_surplus_daily_get(self):
        """Test case for forecast_surplus_daily_get

        Daily surplus forecast (OCNMFD)  # noqa: E501
        """
        pass

    def test_forecast_surplus_daily_history_get(self):
        """Test case for forecast_surplus_daily_history_get

        Historical daily surplus forecast (OCNMFD)  # noqa: E501
        """
        pass

    def test_forecast_surplus_weekly_evolution_get(self):
        """Test case for forecast_surplus_weekly_evolution_get

        Evolution weekly surplus forecast (OCNMFW, OCNMF3Y)  # noqa: E501
        """
        pass

    def test_forecast_surplus_weekly_get(self):
        """Test case for forecast_surplus_weekly_get

        Weekly surplus forecast (OCNMFW, OCNMF3Y)  # noqa: E501
        """
        pass

    def test_forecast_surplus_weekly_history_get(self):
        """Test case for forecast_surplus_weekly_history_get

        Historical weekly surplus forecast (OCNMFW, OCNMF3Y)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.balancing_mechanism_dynamic_api import BalancingMechanismDynamicApi  # noqa: E501
from elexonpy.rest import ApiException


class TestBalancingMechanismDynamicApi(unittest.TestCase):
    """BalancingMechanismDynamicApi unit test stubs"""

    def setUp(self):
        self.api = BalancingMechanismDynamicApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_balancing_dynamic_all_get(self):
        """Test case for balancing_dynamic_all_get

        Market-wide dynamic data (SEL, SIL, MZT, MNZT, MDV, MDP, NTB, NTO, NDZ)  # noqa: E501
        """
        pass

    def test_balancing_dynamic_get(self):
        """Test case for balancing_dynamic_get

        Dynamic data per BMU (SEL, SIL, MZT, MNZT, MDV, MDP, NTB, NTO, NDZ)  # noqa: E501
        """
        pass

    def test_balancing_dynamic_rates_all_get(self):
        """Test case for balancing_dynamic_rates_all_get

        Market-wide rate data (RDRE, RURE, RDRI, RURI)  # noqa: E501
        """
        pass

    def test_balancing_dynamic_rates_get(self):
        """Test case for balancing_dynamic_rates_get

        Rate data per BMU (RDRE, RURE, RDRI, RURI)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiLegacyInteroperabilityLegacyRemitListMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'http_code': 'int',
        'error_type': 'str',
        'description': 'str',
        'capping_applied': 'str',
        'capping_limit': 'int',
        'query_string': 'str'
    }

    attribute_map = {
        'http_code': 'httpCode',
        'error_type': 'errorType',
        'description': 'description',
        'capping_applied': 'cappingApplied',
        'capping_limit': 'cappingLimit',
        'query_string': 'queryString'
    }

    def __init__(self, http_code=None, error_type=None, description=None, capping_applied=None, capping_limit=None, query_string=None):  # noqa: E501
        """InsightsApiLegacyInteroperabilityLegacyRemitListMetadata - a model defined in Swagger"""  # noqa: E501
        self._http_code = None
        self._error_type = None
        self._description = None
        self._capping_applied = None
        self._capping_limit = None
        self._query_string = None
        self.discriminator = None
        if http_code is not None:
            self.http_code = http_code
        if error_type is not None:
            self.error_type = error_type
        if description is not None:
            self.description = description
        if capping_applied is not None:
            self.capping_applied = capping_applied
        if capping_limit is not None:
            self.capping_limit = capping_limit
        if query_string is not None:
            self.query_string = query_string

    @property
    def http_code(self):
        """Gets the http_code of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501


        :return: The http_code of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :rtype: int
        """
        return self._http_code

    @http_code.setter
    def http_code(self, http_code):
        """Sets the http_code of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.


        :param http_code: The http_code of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :type: int
        """

        self._http_code = http_code

    @property
    def error_type(self):
        """Gets the error_type of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501


        :return: The error_type of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :rtype: str
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """Sets the error_type of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.


        :param error_type: The error_type of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :type: str
        """

        self._error_type = error_type

    @property
    def description(self):
        """Gets the description of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501


        :return: The description of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.


        :param description: The description of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def capping_applied(self):
        """Gets the capping_applied of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501


        :return: The capping_applied of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :rtype: str
        """
        return self._capping_applied

    @capping_applied.setter
    def capping_applied(self, capping_applied):
        """Sets the capping_applied of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.


        :param capping_applied: The capping_applied of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :type: str
        """

        self._capping_applied = capping_applied

    @property
    def capping_limit(self):
        """Gets the capping_limit of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501


        :return: The capping_limit of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :rtype: int
        """
        return self._capping_limit

    @capping_limit.setter
    def capping_limit(self, capping_limit):
        """Sets the capping_limit of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.


        :param capping_limit: The capping_limit of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :type: int
        """

        self._capping_limit = capping_limit

    @property
    def query_string(self):
        """Gets the query_string of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501


        :return: The query_string of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :rtype: str
        """
        return self._query_string

    @query_string.setter
    def query_string(self, query_string):
        """Sets the query_string of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.


        :param query_string: The query_string of this InsightsApiLegacyInteroperabilityLegacyRemitListMetadata.  # noqa: E501
        :type: str
        """

        self._query_string = query_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiLegacyInteroperabilityLegacyRemitListMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiLegacyInteroperabilityLegacyRemitListMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
